Welcome to SoaM's documentation!
================================

Contents
--------

.. toctree::
    :maxdepth: 1

    README
    CONTRIBUTING
    end2end
    mlflow_tracking
    project_structure
    classes
    modules




Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
